@@ -76,6 +76,7 @@ public class GmplSwing implements Runnable, GlpkTerminalListener,
         GlpkCallbackListener, ActionListener {
 
     public enum Status {
+
         RUN,
         TERMINATE,
         ABORT
@@ -112,6 +113,7 @@ public class GmplSwing implements Runnable, GlpkTerminalListener,
 
     /**
      * Constructor
+     *
      * @param args command line parameters
      */
     private GmplSwing(String[] args) {
@@ -190,10 +192,16 @@ public class GmplSwing implements Runnable, GlpkTerminalListener,
             if (ret != 0) {
                 GLPK.glp_mpl_free_wksp(tran);
                 GLPK.glp_delete_prob(lp);
+                throw new RuntimeException("Model file not valid: " + fname);
             }
 
             // generate model
-            GLPK.glp_mpl_generate(tran, null);
+            ret = GLPK.glp_mpl_generate(tran, null);
+            if (ret != 0) {
+                GLPK.glp_mpl_free_wksp(tran);
+                GLPK.glp_delete_prob(lp);
+                throw new RuntimeException("Cannot generate model: " + fname);
+            }
             // build model
             GLPK.glp_mpl_build_prob(tran, lp);
             // set solver parameters
@@ -210,7 +218,7 @@ public class GmplSwing implements Runnable, GlpkTerminalListener,
 
             statusLabel.setText("Model has been processed successfully.");
             statusLabel.setForeground(Color.black);
-        } catch (org.gnu.glpk.GlpkException ex) {
+        } catch (RuntimeException ex) {
             statusLabel.setText(ex.getMessage());
             statusLabel.setForeground(Color.red);
         } finally {
@@ -254,6 +262,7 @@ public class GmplSwing implements Runnable, GlpkTerminalListener,
 
     /**
      * Create horizontal splitter
+     *
      * @return horizontal splitter
      */
     private JSplitPane getHorizontalSplitPane() {
@@ -277,6 +286,7 @@ public class GmplSwing implements Runnable, GlpkTerminalListener,
 
     /**
      * This method initializes the frame
+     *
      * @return frame
      */
     private JFrame getJFrame() {
@@ -305,6 +315,7 @@ public class GmplSwing implements Runnable, GlpkTerminalListener,
 
     /**
      * This method initializes the menu bar
+     *
      * @return menu bar
      */
     private JMenuBar getJMenuBar() {
@@ -452,6 +463,7 @@ public class GmplSwing implements Runnable, GlpkTerminalListener,
 
     /**
      * This method initializes the vertical splitter
+     *
      * @return
      */
     private JSplitPane getVerticalSplitPane() {
@@ -494,7 +506,8 @@ public class GmplSwing implements Runnable, GlpkTerminalListener,
     }
 
     /**
-     * Read simulatin model file
+     * Read model file
+     *
      * @param file file
      * @return model
      */
@@ -644,6 +657,7 @@ public class GmplSwing implements Runnable, GlpkTerminalListener,
 
     /**
      * Starts the Application
+     *
      * @param args command line parameters
      */
     public static void main(String[] args) {
@@ -878,8 +892,8 @@ public class GmplSwing implements Runnable, GlpkTerminalListener,
     }
 
     /**
-     * Border style which is etched only on the top, to be used for
-     * the status bar.
+     * Border style which is etched only on the top, to be used for the status
+     * bar.
      */
     private class TopEtchedBorder extends EtchedBorder {
 
